/*
 *      test.c - Test program for working with argument arrays
 * 		Part of the usbsync utility 
 *      
 *      Copyright 2008 Sören Wellhöfer <soeren.wellhoefer@gmx.net>
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

/*
 
  To compile use:
  gcc -g --debug -o test args.c args.h test.c
  
 */

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <string.h>

#include "args.h"

#define BOOL int
#define TRUE  1
#define FALSE 0

void prfx_print_args(FILE *stream, const char *prfx, const char *frm, ARG_ARRAY args) {
       char *str, *format_p, format[16], format_buf[16];
       BOOL p = FALSE;
       void *next_arg;
       
       format_p = format_buf;
       str = (char *)frm;
       bzero(format_buf, sizeof(format_buf));
       fprintf(stream, "%s: ", prfx);
       for( ; *str; str++ ) {
       		if(*str == '\n') fprintf(stream, "\n%s: ", prfx);
       		else if(*str == '\v') { 
       			/* Use vertical tab '\v' as our new line */
				fputc('\n', stream);
			}
       		else if(*str == '%') {
       			p = TRUE;
       		} else if(p) {
       				/* Check if next argument is available */
       				if( !*args ) continue;
       				if( strchr("sdfhc", *str) != NULL ) {
       					*++format_p='\0';
       					sprintf(format, "%%%s%c", format_buf, *str);
       				}
       				/* Retrieve next argument */
       				if( (next_arg = (*args)->argument) == NULL ) continue;
       			switch(*str) {
       				#define ARG_OUT p = FALSE, ++args
       				case 'f':
       					fprintf(stream, format, *(double*)next_arg);
       					ARG_OUT;
       				break;
       				case 's':
       					fprintf(stream, format, (char*)next_arg);
       					ARG_OUT;
       				break;
       				case 'd':
       					fprintf(stream, format, *(int*)next_arg);
       					ARG_OUT;
       				break;
       				case 'h':
       					fprintf(stream,"%x", *(unsigned int*)next_arg);
       					ARG_OUT;
       				break;
       				case 'c':
       					fprintf(stream, "%c", *(char*)next_arg);
       					ARG_OUT;
       				break;
       				default:
       					*format_p++ = *str;
       				break;
       			}
       			if( !p ) {
       				format_p = format_buf;
				}
			} else {
				fputc(*str, stream);
			}  	
	   } 
}

void prfx_print(FILE *stream, const char *prfx, const char *frm, ...) {
	va_list ap;
	ARG_ARRAY args;
	
	/* Initilize variable argument list */
	va_start(ap, frm);
	
	/* Convert variadic argument list to argument array */
	args = varg_to_argarr(frm, &ap);
	
	/* Call printing function */
	prfx_print_args(stdout, prfx, frm, args);

	/* Free argument array and argument list*/
	arg_array_destroy(args);
	va_end(ap);
}

int main() {
	
	int i = 5;
	double q = 2.3;
	char f = 'k';
	
	prfx_print(stdout, "Prefix", "Int:%5d; Str:\"%s\"; Dbl:%f; Chr:%c; Hex: %h; Unk: %b; \v",\
	i, "you fucker", q, f, 14);
	
	prfx_print(stdout, "fw", "hello\v");
	
	prfx_print(stdout, "f", "%2d;%s\v", 5, "sucking");
	
	return 0;
}
