/*
 *      debug.h - Debugging, dumping and synchronization statistics routines
 * 		Part of the usbsync utility 
 *      
 *      
 *      Copyright 2008 Sören Wellhöfer <soeren.wellhoefer@gmx.net>
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#ifndef DEBUG_H
#define DEBUG_H 1

#include "../common.h"
#include "../file.h"
#include "../stack/stack.h"
#include "../error/usbs_errors.h"

/* Verbosity levels */
#define VERBOSE_HIGH 3
#define VERBOSE_MID  2
#define VERBOSE_LOW  1
#define VERBOSE_NON  0


/* Error count, incremented when an error occurs */
extern int error_cnt;
extern int warning_cnt;

/* Statistics variables */
extern int dirs_synced; 
extern int dirs_check;
extern int dirs_skipped;
extern int files_synced; 
extern int files_check;
extern int files_skipped;
extern int files_removed;
extern time_t time_needed;

/* enum for dump type */
enum dump_type {STR, INT, HEX, BOL, CHR, PTR};

/* output functions */
extern void verbose(int level, const char *msg, ... );
extern void print_conclusion();
extern void __init_statistics();
BOOL verbosity_check(int level);

/* Timer routines */
extern void __start_timer();
extern time_t __stop_timer();

/* dumping functions */
extern void dump_usbs_file(USBS_FILE *);
extern void dump_file_stack(STACK *s);
extern void dump_error_message(ERROR_MESSAGE *e);
extern void dump_stack(STACK *s, enum dump_type stack_data);

/* redundant */
extern int _exec_std(void (*), int, ...);

#endif
