/*
 *      usbs_errors.c - Error message initializations for usbsync
 * 		Part of the usbsync utility 
 * 		
 *      Copyright 2008 Sören Wellhöfer <soeren.wellhoefer@gmx.net>
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <settings.h>
#else 
#  define PACKAGE_BUGREPORT   "maintainer"
#endif

#include "usbs_errors.h"

#include <stdio.h>

/* Buffer for error catching. See header file usbs_errors.h */
jmp_buf env;

/* General error message initialization for usbsync.
 * Messages that expect any kind of paramter do this by specifing them
 * in a printf-like manner.
 */ 
ERROR_MESSAGE messages[] = {
	
#define PRIV_ERROR  "Check if program is run with sufficient privileges!\n"\
					" -- This error is common to occur with\n"\
				    " -- file systems that do not support the Unix\n" \
			        " -- concept of file and directory ownership or\n" \
			        " -- of symbolic links.\n" \
				    " -- Try a different file system or try the `-o` option."
	
	/* Fatal errors */
	EM_INIT(ERROR_FATAL_FOPEN,   "Unable to open file:\n\"%s\""),
	EM_INIT(ERROR_FATAL_FGETS,   "Unable to open file:\n\"%s\""),
	EM_INIT(ERROR_FATAL_MALLOC,  "malloc(): Insufficient memory"),
	EM_INIT(ERROR_FATAL_REALLOC, "realloc(): Insufficient memory"),
	EM_INIT(ERROR_FATAL_CRLLOC,  "crealloc: Insufficient memory"),
	EM_INIT(ERROR_FATAL_FSTREAM, "Cannot read from corrupt stream (%h)"),
    EM_INIT(ERROR_FATAL_FDESCR,  "Cannot read from corrupt file descriptor (%h)"),
    EM_INIT(ERROR_FATAL_SEGV,    "Segmentation Fault at %p\n"
								 "Please report this bug to <"PACKAGE_BUGREPORT">"),
	EM_INIT(ERROR_FATAL_PARSING, "Parsing \"%s\" failed"),
	EM_INIT(ERROR_FATAL_USBSYNC, "Given usbsync file name is too long:\n\"%s\""),
    
	
	/* Warnings */
	EM_INIT(ERROR_WARNING_DRCBN, "Directory recursion halted at level %d:\n"\
								 "Make sure there are no path cycles.\n"\
								 "To ignore this preset boundary,\ntry the `-e' or `-d' options."),
	EM_INIT(ERROR_WARNING_PRIV,  "Programe was executed with low privileges.\n"\
								 "This could have resulted in various privilege errors.\n"\
								 "Make sure to have the usbsync binary be owned by root\n"\
								 "and to have `chmod u+s' run on it."),
	EM_INIT(ERROR_WARNING_UPRIV, "Executing user (uid=%d) might not be endowed with sufficient\n"\
								 "privileges to take action for user (uid=%d) given in \"%s\""),
	EM_INIT(ERROR_WARNING_ETCPSWD,"User (uid=%d) does appear not to have\n"
				                  "user information available in \"%s\""), 
	
	/* Normal errors */
	EM_INIT(ERROR_ERROR_LSTAT,   "Cannot retrieve file information for file:\n\"%s\""),
	EM_INIT(ERROR_ERROR_SDUMP,   "Dump not possible (null)"),
	EM_INIT(ERROR_ERROR_MEDIUM,  "No mountpoint of storage volume given as an argument.\n"\
    							 "Mountpoint is the directory where volume is mounted."),
    EM_INIT(ERROR_ERROR_TGETHER, "Option `-q, --quiet' must not be used together\n"\
								 "with option `--prompt-update' or option `--single-file'."),
	EM_INIT(ERROR_ERROR_VLEVEL,  "Invalid verbosity level: %d"),
	EM_INIT(ERROR_ERROR_DREC,    "Invalid directory recursion level given: %d"),
	EM_INIT(ERROR_ERROR_LSTAT,   "Cannot retrieve information for: \n\"%s\""),
	EM_INIT(ERROR_ERROR_MODTIME, "Updating modification times: File(s) do not exist:\n\"%s\"\n\"%s\""),
	EM_INIT(ERROR_ERROR_UTIME,   "Setting modifcation time failed:\n"
								 "\"%s\""),
	EM_INIT(ERROR_ERROR_MTUPDT,  "Updating modifcation times: Could not equate"
								 "mod times of symlink and its target:\n\"%s\""),
	EM_INIT(ERROR_ERROR_BYWRIT,  "File descriptor became prematurely invalid:"
								 "\nFile:\"%s\""),
	EM_INIT(ERROR_ERROR_FFLUSH,  "Unable to flush file descriptor open to file:\n%s"),
	EM_INIT(ERROR_ERROR_FDCLOSE, "Error when trying to close file descriptor."),
	EM_INIT(ERROR_ERROR_SETMTM,  "Error when setting modifcation time"),
	EM_INIT(ERROR_ERROR_RDLNK,   "Reading symbolic link failed:\n\"%s\""),
	EM_INIT(ERROR_ERROR_CSYMLNK, "Creating new symbolic link failed:\n\"%s\"\nIf set,"
								 "try to rerun without the `-l' option.\n" PRIV_ERROR),
	EM_INIT(ERROR_ERROR_SLEQMTIME, "Failed to equate symlink modification times:\n\"%s\"n\"%s\""),
	EM_INIT(ERROR_ERROR_FOPEN,   "Unable to open file:\n\"%s\""),
	EM_INIT(ERROR_ERROR_FGETS,   "Unable to open file:\n\"%s\""),
	EM_INIT(ERROR_ERROR_FSTREAM, "Cannot read from corrupt stream (%p)"),
    EM_INIT(ERROR_ERROR_FDESCR,  "Cannot read from corrupt file descriptor (%h)"),
    EM_INIT(ERROR_ERROR_SDATA,   "Invalid syncdata structure to be destroyed"),
    EM_INIT(ERROR_ERROR_USBCHOWN,"Directory/ies created or file/s copied, but unable\n"\
    							 "to properly set group and user ownership:\n\"%s\"\n"\
							 	 "uid=%d, gid=%d\n" PRIV_ERROR),
	EM_INIT(ERROR_ERROR_GETCWD,  "Unable to determine current working directory (cwd)."),
	EM_INIT(ERROR_ERROR_CHMOD,   "Unable to set file mode:\n\"%s\"\n" PRIV_ERROR),
	EM_INIT(ERROR_ERROR_FRMTERR, "Cannot format time string."),
	EM_INIT(ERROR_ERROR_FILELEN, "Filename is too long."),
	EM_INIT(ERROR_ERROR_STRFRMT, "Time '%d' (epoch) could not be formatted\n to time string."),
    EM_INIT(ERROR_ERROR_DIRFILE, "%s:%d:\nInvalid association: Associating directory\n"
								 "with file:\nDirect.: \"%s\"\nFile: \"%s\""),
	EM_INIT(ERROR_ERROR_EXIST,   "%s:%d: File or directory error\n\"%s\"\n\"%s\"\n"
								 "At least one of both files or directories must exist!"),
	EM_INIT(ERROR_ERROR_DIROPN,  "Cannot open directory for scanning:\n\"%s\""),
	EM_INIT(ERROR_ERROR_PATHERR, "%s path: \"%s\"\nPath syntax/semantics validation failed."),
	EM_INIT(ERROR_ERROR_DIRREC,  "Breaking directory recursion: Invalid sub-level reached"),
	EM_INIT(ERROR_ERROR_MKDIR,   "Unable to create directory:\n\"%s\"\n"
		                         "Check if program is run with sufficient privileges."),
	EM_INIT(ERROR_ERROR_ACCESS,  "Cannot access file or directory:\n\"%s\""),
	EM_INIT(ERROR_ERROR_BACKUP,  "Unable to create backup file:\nSrc.:\"%s\"\nDst.:\"%s\""),
	EM_INIT(ERROR_ERROR_SYNSEM,  "%s:%d\nSyntax/Semantics error: Please check file at given line."),
	EM_INIT(ERROR_ERROR_SYNLIN,  "%s:%d: Syntax error:\n` %s '"),
	EM_INIT(ERROR_ERROR_SEMLIN,  "%s:%d: Semantics error:\nInvalid identifier\n` %s '"),
	EM_INIT(ERROR_ERROR_MALFRM,  "%s:%d:\nMalformatted line; key components are missing.\n\"%s\""),
	EM_INIT(ERROR_ERROR_USRCHO,  "Internal error: Invalidity in user choice detected"),
	EM_INIT(ERROR_ERROR_PATHEX,  "Unable to to expand relative path to absolute"
								 "path of uid=%d:\n\"%s\""),
	EM_INIT(ERROR_ERROR_FASSOC,  "%s:%d:\nNo association set or found for file or directory:\n\"%s\""),
	EM_INIT(ERROR_ERROR_NOHOST,  "%s:%d:\nNo host found to synchronize with. "
								 "File or directory:\n\"%s\""),
	EM_INIT(ERROR_ERROR_INVSTA,  "Empty or invalid file stack\n(No files to be synchronized)"),
	EM_INIT(ERROR_ERROR_UNLINK,  "Unlinking file filed:\n\"%s\""),
	EM_INIT(ERROR_ERROR_PATH,    "%s path is too long:\n\"%s\""),
	EM_INIT(ERROR_ERROR_IOPT,    "%s:%d: Invalid option:\n` %s '"),
	 
	ZERO_TERMINATE
   
};
