/*
 *      usbs_errors.h - Error message codes for usbsync
 * 		Part of the usbsync utility 
 * 		
 *      Copyright 2008 Sören Wellhöfer <soeren.wellhoefer@gmx.net>
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#ifndef USBS_ERRORS_H
#define USBS_ERRORS_H 1

#include "error.h"

#include <setjmp.h>


/* 
 * Usbsync error codes and their symbolic names
 */
enum {
	/* Fatal errors 1 to 99 */
	ERROR_FATAL_FOPEN   = 1,
	ERROR_FATAL_FGETS   = 2,
	ERROR_FATAL_MALLOC  = 3,
	ERROR_FATAL_REALLOC = 4,
	ERROR_FATAL_CRLLOC  = 5,
	ERROR_FATAL_FSTREAM = 6,
	ERROR_FATAL_FDESCR  = 7, 
	ERROR_FATAL_SEGV    = 8,
	ERROR_FATAL_PARSING = 9,
	ERROR_FATAL_USBSYNC = 10,
	
	/* Warnings 100 to 199 */
	ERROR_WARNING_TOO_OLD = 100, /* FIXME: Unused ? */ 
	ERROR_WARNING_DRCBN = 101,
	ERROR_WARNING_PRIV = 102,
	ERROR_WARNING_UPRIV = 103,
	ERROR_WARNING_ETCPSWD = 104,
	
	/* Normal and parse errors 200 and beyond */
	ERROR_ERROR_LSTAT = 201,
	ERROR_ERROR_SDUMP = 202,
	ERROR_ERROR_MEDIUM  = 203,
	ERROR_ERROR_TGETHER = 204,
	ERROR_ERROR_VLEVEL  = 205,
	ERROR_ERROR_DREC = 206,
	ERROR_ERROR_MODTIME = 207,
	ERROR_ERROR_UTIME = 208,
	ERROR_ERROR_MTUPDT = 209,
	ERROR_ERROR_BYWRIT = 211,
	ERROR_ERROR_FFLUSH = 212,
	ERROR_ERROR_FDCLOSE = 213,
	ERROR_ERROR_SETMTM = 214,
	ERROR_ERROR_RDLNK = 215,
	ERROR_ERROR_CSYMLNK = 216, 
	ERROR_ERROR_SLEQMTIME = 217,
	ERROR_ERROR_FOPEN   = 218,
	ERROR_ERROR_FGETS   = 219,
	ERROR_ERROR_FSTREAM = 220,
	ERROR_ERROR_FDESCR = 221,
	ERROR_ERROR_SDATA = 222,
	ERROR_ERROR_USBCHOWN = 223,
	ERROR_ERROR_GETCWD = 224,
	ERROR_ERROR_CHMOD = 225,
	ERROR_ERROR_FRMTERR = 226,
	ERROR_ERROR_PATHLEN = 227,
	ERROR_ERROR_FILELEN = 228,
	ERROR_ERROR_STRFRMT = 229,
	ERROR_ERROR_DIRFILE = 230, 
	ERROR_ERROR_EXIST = 231,
	ERROR_ERROR_DIROPN = 232,
	ERROR_ERROR_PATHERR = 233,
	ERROR_ERROR_DIRREC = 234,
	ERROR_ERROR_MKDIR  = 235,
	ERROR_ERROR_ACCESS = 236,
	ERROR_ERROR_BACKUP = 237,
	ERROR_ERROR_SYNSEM = 238,
	ERROR_ERROR_SYNLIN = 239,
	ERROR_ERROR_SEMLIN = 240,
	ERROR_ERROR_MALFRM = 241,
	ERROR_ERROR_USRCHO = 242,
	ERROR_ERROR_PATHEX = 243,
	ERROR_ERROR_FASSOC = 244,
	ERROR_ERROR_NOHOST = 245,
	ERROR_ERROR_INVSTA = 246,
	ERROR_ERROR_UNLINK = 247,
	ERROR_ERROR_PATH   = 248,
	ERROR_ERROR_IOPT   = 249,
	
};


#endif /* USBS_ERRORS_H */
