/*
 *      options.c - Usbsync command line option handling
 *		Part of the usbsync utility 
 *      
 *      Copyright 2008 Sören Wellhöfer <soeren.wellhoefer@gmx.net>
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include "options.h"

#include <stdio.h>

/* Options that can be set during run time are encoded in bitmask */
static OPTION options;

/**
 * Initializes the options to 0.
 */
void _init_options() {
	options = _OPTION_NONE;
}

/**
 * Checks, according to the "options" bitmask, and the value
 * option given, if a certain option is set.
 */
BOOL _option_check(OPTION option) {
	if( (options & option) == option ) return TRUE;
	return FALSE;
}

/** 
 * Set an application option.
 */
void _option_set(OPTION option) {
	options |= option;
}

/**
 * Remove a set option.
 */
void _option_rmv(OPTION option) {
	options &= ~option;
}

/**
 * Debugging
 */
void _option_print() {
	printf("Options bitmask: %X\n", (unsigned short)options);
}
