/*
 *      path.h - Working with path, file and directory names
 *		Part of the usbsync utility 
 * 		
 *      Copyright 2008 Sören Wellhöfer <soeren.wellhoefer@gmx.net>
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#ifndef PATH_H
#define PATH_H 1

#include <unistd.h>

#include "common.h"

/* String used to substitute multiple directories in the PNN_() function */
#define DIRS_SHORTENED "..."

/* Path types; for validate_path_syntax function. See below. */
enum path_type {RELPATH = 0, ABSPATH, HOMEPATH};

/* String name of path types for output */
extern const char *path_type_names[];

extern char* expand_tilde_path(char *abs_path, char *tilde_path, uid_t uid);
extern char* FN_(const char *fname);
extern char* PN_(const char *path, BOOL is_file);
extern char* PNN_(const char *path, enum path_type ptype, size_t path_max_len, BOOL is_file);
extern char* concat_m_dirs(char *buf, int n, ...);
extern BOOL validate_path_syntax(const char *path, enum path_type ptype);
extern BOOL validate_host_path(const char *hpath);
extern BOOL validate_usb_path(const char *upath);
extern BOOL check_path_length(const char *path_name, const char *path, size_t tol);

extern int MAX_FNAME_LEN;
extern int MAX_PATHN_LEN;

extern void __init_path_display();
extern void __deinit_path_display();


#endif


