/*
 *      stack.h - part of the usbsync utility 
 *      
 *      Copyright 2008 Sören Wellhöfer <soeren.wellhoefer@gmx.net>
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#ifndef STACK_H
#define STACK_H 1

/* Defined if stack is not simply used as a simple data stack.
 * See stack_type field of the stack down below.
 */
#define MULTISTACK

#ifdef MULTISTACK
/* Names of different stack types; see stack_type field in structure. */
extern const char *stack_type_names[];
#endif

/*
 * Element of a stack.
 */
typedef struct __STACK_ELEMENT STACK_ELEMENT; 

struct __STACK_ELEMENT {
	void *data;
	STACK_ELEMENT *next;
};

/**
 * Structure for a general stack.
 */
typedef struct {
	STACK_ELEMENT *top;  /* Top element */
	int count;           /* Current num of elements on stack */
	
	/* Type of stack to add certain distinctive 
	 * functionality for each different stack
	 */
#ifdef MULTISTACK
	enum {
		NORMAL_STACK = 0,
		FILE_STACK,  	 /* Stack contains USBS_FILE objects */
		ERROR_STACK,     /* Stack is error stack; see error/error.h */
		SYNCDATA_STACK   /* Stack is stack containing USBS_SYNCDATA structs */
	} stack_type;
#endif
} STACK;

/* new/destroy stack */
extern STACK* stack_new();
extern void stack_destroy(STACK **); 

/* abstract data type operations */
extern int stack_push(STACK *, void *);
extern int stack_pop(STACK *, int destroy);
extern int stack_str_pushed(STACK *s, const char *str); 

#endif
